$.i18n().load({
    "en": {
        "regex_title": "REGULAR EXPRESSION",
        "flag_title": "FLAGS",
        "text_title": "TEST STRING",
        "button_text": "SHOW RESULT",
        "button_test" : "TEST ANSWER",
        "correct": "Correct",
        "incorrect" : "Wrong",
    }
})